vty: allow configuring db path from cfg file

So far, the cmdline argument was the only way to set a database file.
Add a similar config to VTY as 'msc' / 'sms-database'. The cmdline arg is stronger
than the 'database' cfg item. DB is not reloaded from VTY command.

Change-Id: I18d954c30fcceb0b36a620b927fd3a93dcc79f49
diff --git a/tests/msc_vlr/msc_vlr_test_authen_reuse.err b/tests/msc_vlr/msc_vlr_test_authen_reuse.err
index f00470a..7e6f261 100644
--- a/tests/msc_vlr/msc_vlr_test_authen_reuse.err
+++ b/tests/msc_vlr/msc_vlr_test_authen_reuse.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_auth_use_twice_geran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -510,7 +510,7 @@
 ===== test_auth_use_twice_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_auth_use_twice_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1042,7 +1042,7 @@
 ===== test_auth_use_twice_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_auth_use_infinitely_geran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1658,7 +1658,7 @@
 ===== test_auth_use_infinitely_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_auth_use_infinitely_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2302,7 +2302,7 @@
 ===== test_auth_use_infinitely_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_auth_reuse_geran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2694,7 +2694,7 @@
 ===== test_no_auth_reuse_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_auth_reuse_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -3102,8 +3102,8 @@
 ===== test_no_auth_reuse_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_call.err b/tests/msc_vlr/msc_vlr_test_call.err
index 337483c..21ccd2c 100644
--- a/tests/msc_vlr/msc_vlr_test_call.err
+++ b/tests/msc_vlr/msc_vlr_test_call.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_call_mo
 - Total time passed: 0.000000 s
@@ -474,7 +474,7 @@
 ===== test_call_mo: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_call_mt
 - Total time passed: 0.000000 s
@@ -945,7 +945,7 @@
 ===== test_call_mt: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_call_mt2
 - Total time passed: 0.000000 s
@@ -1370,7 +1370,7 @@
 ===== test_call_mt2: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_call_mo_to_unknown
 - Total time passed: 0.000000 s
@@ -1798,7 +1798,7 @@
 ===== test_call_mo_to_unknown: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_call_mo_to_unknown_timeout
 - Total time passed: 0.000000 s
@@ -2222,8 +2222,8 @@
 ===== test_call_mo_to_unknown_timeout: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_gsm_authen.err b/tests/msc_vlr/msc_vlr_test_gsm_authen.err
index 94a257d..3677a36 100644
--- a/tests/msc_vlr/msc_vlr_test_gsm_authen.err
+++ b/tests/msc_vlr/msc_vlr_test_gsm_authen.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_gsm_authen
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -590,7 +590,7 @@
 ===== test_gsm_authen: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_gsm_authen_tmsi
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1421,7 +1421,7 @@
 ===== test_gsm_authen_tmsi: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_gsm_authen_imei
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1735,7 +1735,7 @@
 ===== test_gsm_authen_imei: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_gsm_authen_imei_nack
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2002,7 +2002,7 @@
 ===== test_gsm_authen_imei_nack: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_gsm_authen_imei_err
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2270,7 +2270,7 @@
 ===== test_gsm_authen_imei_err: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_gsm_authen_tmsi_imei
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2625,7 +2625,7 @@
 ===== test_gsm_authen_tmsi_imei: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_gsm_milenage_authen
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -3189,7 +3189,7 @@
 ===== test_gsm_milenage_authen: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_wrong_sres_length
 - Total time passed: 0.000000 s
@@ -3334,8 +3334,8 @@
 ===== test_wrong_sres_length: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_gsm_ciph.err b/tests/msc_vlr/msc_vlr_test_gsm_ciph.err
index 53e8ee6..2410ff6 100644
--- a/tests/msc_vlr/msc_vlr_test_gsm_ciph.err
+++ b/tests/msc_vlr/msc_vlr_test_gsm_ciph.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ciph
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -658,7 +658,7 @@
 ===== test_ciph: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ciph_tmsi
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1364,7 +1364,7 @@
 ===== test_ciph_tmsi: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ciph_imei
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1685,7 +1685,7 @@
 ===== test_ciph_imei: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ciph_imeisv
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1971,7 +1971,7 @@
 ===== test_ciph_imeisv: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ciph_tmsi_imei
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2333,7 +2333,7 @@
 ===== test_ciph_tmsi_imei: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_gsm_ciph_in_umts_env
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2936,7 +2936,7 @@
 ===== test_gsm_ciph_in_umts_env: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_a5_3_supported
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -3586,7 +3586,7 @@
 ===== test_a5_3_supported: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_cm_service_needs_classmark_update
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -4214,8 +4214,8 @@
 ===== test_cm_service_needs_classmark_update: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_hlr_reject.err b/tests/msc_vlr/msc_vlr_test_hlr_reject.err
index d115d48..d4ed53a 100644
--- a/tests/msc_vlr/msc_vlr_test_hlr_reject.err
+++ b/tests/msc_vlr/msc_vlr_test_hlr_reject.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_rej_auth_info_unknown_imsi
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -101,7 +101,7 @@
 ===== test_hlr_rej_auth_info_unknown_imsi: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_rej_auth_info_net_fail
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -202,7 +202,7 @@
 ===== test_hlr_rej_auth_info_net_fail: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_rej_auth_info_net_fail_reuse_tuples
 
@@ -532,7 +532,7 @@
 ===== test_hlr_rej_auth_info_net_fail_reuse_tuples: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_rej_auth_info_net_fail_no_reuse_tuples
 
@@ -800,7 +800,7 @@
 ===== test_hlr_rej_auth_info_net_fail_no_reuse_tuples: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_rej_auth_info_unkown_imsi_no_reuse_tuples
 
@@ -1069,7 +1069,7 @@
 ===== test_hlr_rej_auth_info_unkown_imsi_no_reuse_tuples: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_acc_but_no_auth_tuples
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1169,7 +1169,7 @@
 ===== test_hlr_acc_but_no_auth_tuples: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_rej_lu
 - Location Update request causes a GSUP LU request to HLR
@@ -1274,7 +1274,7 @@
 ===== test_hlr_rej_lu: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_no_insert_data
 - Location Update request causes a GSUP LU request to HLR
@@ -1392,8 +1392,8 @@
 ===== test_hlr_no_insert_data: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_hlr_timeout.err b/tests/msc_vlr/msc_vlr_test_hlr_timeout.err
index 07fb621..51aa913 100644
--- a/tests/msc_vlr/msc_vlr_test_hlr_timeout.err
+++ b/tests/msc_vlr/msc_vlr_test_hlr_timeout.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_timeout_lu_auth_info
 - Total time passed: 0.000000 s
@@ -110,7 +110,7 @@
 ===== test_hlr_timeout_lu_auth_info: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_hlr_timeout_lu_upd_loc_result
 - Total time passed: 0.000000 s
@@ -239,8 +239,8 @@
 ===== test_hlr_timeout_lu_upd_loc_result: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_ms_timeout.err b/tests/msc_vlr/msc_vlr_test_ms_timeout.err
index 2405b65..a64672a 100644
--- a/tests/msc_vlr/msc_vlr_test_ms_timeout.err
+++ b/tests/msc_vlr/msc_vlr_test_ms_timeout.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ms_timeout_lu_auth_resp
 - Total time passed: 0.000000 s
@@ -129,7 +129,7 @@
 ===== test_ms_timeout_lu_auth_resp: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ms_timeout_cm_auth_resp
 - Total time passed: 0.000000 s
@@ -404,7 +404,7 @@
 ===== test_ms_timeout_cm_auth_resp: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ms_timeout_paging
 - Total time passed: 0.000000 s
@@ -714,7 +714,7 @@
 ===== test_ms_timeout_paging: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_classmark_update_timeout
 - Total time passed: 0.000000 s
@@ -867,8 +867,8 @@
 ===== test_classmark_update_timeout: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_no_authen.err b/tests/msc_vlr/msc_vlr_test_no_authen.err
index 236aacd..a353949 100644
--- a/tests/msc_vlr/msc_vlr_test_no_authen.err
+++ b/tests/msc_vlr/msc_vlr_test_no_authen.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_authen
 - Location Update request causes a GSUP LU request to HLR
@@ -457,7 +457,7 @@
 ===== test_no_authen: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_authen_tmsi
 - Location Update request causes a GSUP LU request to HLR
@@ -1148,7 +1148,7 @@
 ===== test_no_authen_tmsi: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_authen_imei
 - Location Update request causes a GSUP LU request to HLR
@@ -1401,7 +1401,7 @@
 ===== test_no_authen_imei: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_authen_tmsi_imei
 - Location Update request causes a GSUP LU request to HLR
@@ -1689,7 +1689,7 @@
 ===== test_no_authen_tmsi_imei: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_authen_imeisv
 - Location Update request causes an IMEISV ID request back to the MS
@@ -1912,7 +1912,7 @@
 ===== test_no_authen_imeisv: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_authen_imeisv_imei
 - Location Update request causes an IMEISV ID request back to the MS
@@ -2146,7 +2146,7 @@
 ===== test_no_authen_imeisv_imei: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_authen_imeisv_tmsi
 - Location Update request causes an IMEISV ID request back to the MS
@@ -2616,7 +2616,7 @@
 ===== test_no_authen_imeisv_tmsi: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_authen_imeisv_tmsi_imei
 - Location Update request causes an IMEISV ID request back to the MS
@@ -2887,7 +2887,7 @@
 ===== test_no_authen_imeisv_tmsi_imei: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_no_authen_subscr_expire
 - Total time passed: 0.000000 s
@@ -3024,8 +3024,8 @@
 ===== test_no_authen_subscr_expire: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_reject_concurrency.err b/tests/msc_vlr/msc_vlr_test_reject_concurrency.err
index 9b780c5..9faec63 100644
--- a/tests/msc_vlr/msc_vlr_test_reject_concurrency.err
+++ b/tests/msc_vlr/msc_vlr_test_reject_concurrency.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_reject_2nd_conn
 - Location Update Request on one connection
@@ -192,7 +192,7 @@
 ===== test_reject_2nd_conn: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_reject_lu_during_lu
 - Location Update Request
@@ -335,7 +335,7 @@
 ===== test_reject_lu_during_lu: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_reject_cm_during_lu
 - Location Update Request
@@ -483,7 +483,7 @@
 ===== test_reject_cm_during_lu: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_reject_paging_resp_during_lu
 - Location Update Request
@@ -625,7 +625,7 @@
 ===== test_reject_paging_resp_during_lu: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_reject_lu_during_cm
 
@@ -865,7 +865,7 @@
 ===== test_reject_lu_during_cm: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_reject_cm_during_cm
 
@@ -1110,7 +1110,7 @@
 ===== test_reject_cm_during_cm: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_reject_paging_resp_during_cm
 
@@ -1339,7 +1339,7 @@
 ===== test_reject_paging_resp_during_cm: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_reject_lu_during_paging_resp
 
@@ -1643,7 +1643,7 @@
 ===== test_reject_lu_during_paging_resp: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_accept_cm_during_paging_resp
 
@@ -1971,7 +1971,7 @@
 ===== test_accept_cm_during_paging_resp: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_reject_paging_resp_during_paging_resp
 
@@ -2272,8 +2272,8 @@
 ===== test_reject_paging_resp_during_paging_resp: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_rest.err b/tests/msc_vlr/msc_vlr_test_rest.err
index 51b27db..5e44f31 100644
--- a/tests/msc_vlr/msc_vlr_test_rest.err
+++ b/tests/msc_vlr/msc_vlr_test_rest.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_cm_service_without_lu
 - CM Service Request without a prior Location Updating
@@ -65,7 +65,7 @@
 ===== test_cm_service_without_lu: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_two_lu
 - Location Update request causes a GSUP LU request to HLR
@@ -408,7 +408,7 @@
 ===== test_two_lu: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_lu_unknown_tmsi
 - Location Update request with unknown TMSI sends ID Request for IMSI
@@ -590,8 +590,8 @@
 ===== test_lu_unknown_tmsi: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_ss.err b/tests/msc_vlr/msc_vlr_test_ss.err
index ca18094..3b324d3 100644
--- a/tests/msc_vlr/msc_vlr_test_ss.err
+++ b/tests/msc_vlr/msc_vlr_test_ss.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ss_ussd_mo_geran
 - Location Update request causes a GSUP LU request to HLR
@@ -241,7 +241,7 @@
 ===== test_ss_ussd_mo_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_ss_ussd_no_geran
 - Location Update request causes a GSUP LU request to HLR
@@ -507,8 +507,8 @@
 ===== test_ss_ussd_no_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/msc_vlr/msc_vlr_test_umts_authen.err b/tests/msc_vlr/msc_vlr_test_umts_authen.err
index 7f345a1..42ed422 100644
--- a/tests/msc_vlr/msc_vlr_test_umts_authen.err
+++ b/tests/msc_vlr/msc_vlr_test_umts_authen.err
@@ -1,6 +1,6 @@
 DLMGCP MGCP client: using endpoint domain '@mgw'
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_geran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -608,7 +608,7 @@
 ===== test_umts_authen_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1216,7 +1216,7 @@
 ===== test_umts_authen_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_auth_ciph_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -1848,7 +1848,7 @@
 ===== test_umts_auth_ciph_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_resync_geran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2082,7 +2082,7 @@
 ===== test_umts_authen_resync_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_resync_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2316,7 +2316,7 @@
 ===== test_umts_authen_resync_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_auth_ciph_resync_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2560,7 +2560,7 @@
 ===== test_umts_auth_ciph_resync_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_too_short_res_geran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2678,7 +2678,7 @@
 ===== test_umts_authen_too_short_res_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_too_short_res_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2796,7 +2796,7 @@
 ===== test_umts_authen_too_short_res_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_too_long_res_geran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -2914,7 +2914,7 @@
 ===== test_umts_authen_too_long_res_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_too_long_res_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -3032,7 +3032,7 @@
 ===== test_umts_authen_too_long_res_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_only_sres_geran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -3150,7 +3150,7 @@
 ===== test_umts_authen_only_sres_geran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 ===== test_umts_authen_only_sres_utran
 - Location Update request causes a GSUP Send Auth Info request to HLR
@@ -3268,8 +3268,8 @@
 ===== test_umts_authen_only_sres_utran: SUCCESS
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
 full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-talloc_total_blocks(tall_bsc_ctx) == 20
+talloc_total_blocks(tall_bsc_ctx) == 21
 
diff --git a/tests/test_nodes.vty b/tests/test_nodes.vty
index 520f07c..d389675 100644
--- a/tests/test_nodes.vty
+++ b/tests/test_nodes.vty
@@ -46,6 +46,7 @@
 OsmoMSC(config)# msc
 OsmoMSC(config-msc)# list
 ...
+  sms-database PATH
   assign-tmsi
   mncc internal
   mncc external MNCC_SOCKET_PATH
diff --git a/tests/msc_vlr/msc_vlr_tests.c b/tests/msc_vlr/msc_vlr_tests.c
index 21af3ca..07a3927 100644
--- a/tests/msc_vlr/msc_vlr_tests.c
+++ b/tests/msc_vlr/msc_vlr_tests.c
@@ -1049,31 +1049,32 @@
 	talloc_report_full(msgb_ctx, stderr);
 	/* Expecting these to stick around in msc_vlr_tests_ctx:
 	 * full talloc report on 'msgb' (total      0 bytes in   1 blocks)
 	 * talloc_total_blocks(tall_bsc_ctx) == 20
 	 * full talloc report on 'msc_vlr_tests_ctx' (total   6556 bytes in  20 blocks)
 	 *      struct osmo_gsup_client        contains    264 bytes in   1 blocks (ref 0) 0x613000000260
 	 *      struct gsm_network             contains   4791 bytes in  12 blocks (ref 0) 0x6190000000e0
 	 *       struct mgcp_client             contains    688 bytes in   1 blocks (ref 0) 0x6180000000e0
 	 *       struct sccp_ran_inst           contains    152 bytes in   1 blocks (ref 0) 0x611000000320
 	 *       struct sccp_ran_inst           contains    152 bytes in   1 blocks (ref 0) 0x6110000001e0
 	 *       struct gsup_client_mux         contains    152 bytes in   2 blocks (ref 0) 0x6100000001a0
 	 *           struct ipaccess_unit           contains     64 bytes in   1 blocks (ref 0) 0x60e000023180
 	 *       struct vlr_instance            contains    264 bytes in   2 blocks (ref 0) 0x6130000000a0
 	 *           struct osmo_nri_ranges         contains     16 bytes in   1 blocks (ref 0) 0x60b000000360
 	 *       no_gsup_server                 contains     15 bytes in   1 blocks (ref 0) 0x60b0000002b0
 	 *       ../../../src/libosmocore/src/stat_item.c:96 contains    144 bytes in   2 blocks (ref 0) 0x60d000000170
 	 *           ../../../src/libosmocore/src/stat_item.c:118 contains     96 bytes in   1 blocks (ref 0) 0x6100000000a0
 	 *       ../../../src/libosmocore/src/rate_ctr.c:234 contains   2352 bytes in   1 blocks (ref 0) 0x61e0000000e0
 	 *      logging                        contains   1501 bytes in   5 blocks (ref 0) 0x60b000000200
 	 *       struct log_target              contains    244 bytes in   2 blocks (ref 0) 0x6120000000a0
 	 *           struct log_category            contains     76 bytes in   1 blocks (ref 0) 0x60f0000000a0
 	 *       struct log_info                contains   1256 bytes in   2 blocks (ref 0) 0x60d0000000a0
 	 *           struct log_info_cat            contains   1216 bytes in   1 blocks (ref 0) 0x61a0000000e0
 	 *      msgb                           contains      0 bytes in   1 blocks (ref 0) 0x608000000180
 	 */
 	fprintf(stderr, "talloc_total_blocks(tall_bsc_ctx) == %zu\n",
 		talloc_total_blocks(msc_vlr_tests_ctx));
-	if (talloc_total_blocks(msc_vlr_tests_ctx) != 20)
+	if (talloc_total_blocks(msc_vlr_tests_ctx) != 21)
 		talloc_report_full(msc_vlr_tests_ctx, stderr);
 	fprintf(stderr, "\n");
 }
@@ -1049,31 +1049,32 @@
 	/* Expecting these to stick around in msc_vlr_tests_ctx:
 	 * full talloc report on 'msgb' (total      0 bytes in   1 blocks)
-	 * talloc_total_blocks(tall_bsc_ctx) == 20
-	 * full talloc report on 'msc_vlr_tests_ctx' (total   6556 bytes in  20 blocks)
-	 *      struct osmo_gsup_client        contains    264 bytes in   1 blocks (ref 0) 0x613000000260
-	 *      struct gsm_network             contains   4791 bytes in  12 blocks (ref 0) 0x6190000000e0
-	 *       struct mgcp_client             contains    688 bytes in   1 blocks (ref 0) 0x6180000000e0
-	 *       struct sccp_ran_inst           contains    152 bytes in   1 blocks (ref 0) 0x611000000320
-	 *       struct sccp_ran_inst           contains    152 bytes in   1 blocks (ref 0) 0x6110000001e0
-	 *       struct gsup_client_mux         contains    152 bytes in   2 blocks (ref 0) 0x6100000001a0
-	 *           struct ipaccess_unit           contains     64 bytes in   1 blocks (ref 0) 0x60e000023180
-	 *       struct vlr_instance            contains    264 bytes in   2 blocks (ref 0) 0x6130000000a0
-	 *           struct osmo_nri_ranges         contains     16 bytes in   1 blocks (ref 0) 0x60b000000360
-	 *       no_gsup_server                 contains     15 bytes in   1 blocks (ref 0) 0x60b0000002b0
-	 *       ../../../src/libosmocore/src/stat_item.c:96 contains    144 bytes in   2 blocks (ref 0) 0x60d000000170
-	 *           ../../../src/libosmocore/src/stat_item.c:118 contains     96 bytes in   1 blocks (ref 0) 0x6100000000a0
-	 *       ../../../src/libosmocore/src/rate_ctr.c:234 contains   2352 bytes in   1 blocks (ref 0) 0x61e0000000e0
-	 *      logging                        contains   1501 bytes in   5 blocks (ref 0) 0x60b000000200
-	 *       struct log_target              contains    244 bytes in   2 blocks (ref 0) 0x6120000000a0
-	 *           struct log_category            contains     76 bytes in   1 blocks (ref 0) 0x60f0000000a0
-	 *       struct log_info                contains   1256 bytes in   2 blocks (ref 0) 0x60d0000000a0
-	 *           struct log_info_cat            contains   1216 bytes in   1 blocks (ref 0) 0x61a0000000e0
-	 *      msgb                           contains      0 bytes in   1 blocks (ref 0) 0x608000000180
+	 * talloc_total_blocks(tall_bsc_ctx) == 21
+	 * full talloc report on 'msc_vlr_tests_ctx' (total   6571 bytes in  21 blocks)
+	 *     struct osmo_gsup_client        contains    264 bytes in   1 blocks (ref 0) 0x5605f2ea2e90
+	 *     struct gsm_network             contains   4806 bytes in  13 blocks (ref 0) 0x5605f2ea1b60
+	 *         struct mgcp_client             contains    688 bytes in   1 blocks (ref 0) 0x5605f2ea3200
+	 *         struct sccp_ran_inst           contains    152 bytes in   1 blocks (ref 0) 0x5605f2ea3100
+	 *         struct sccp_ran_inst           contains    152 bytes in   1 blocks (ref 0) 0x5605f2ea3000
+	 *         struct gsup_client_mux         contains    152 bytes in   2 blocks (ref 0) 0x5605f2ea2d20
+	 *             struct ipaccess_unit           contains     64 bytes in   1 blocks (ref 0) 0x5605f2ea2de0
+	 *         struct vlr_instance            contains    264 bytes in   2 blocks (ref 0) 0x5605f2ea2b40
+	 *             struct osmo_nri_ranges         contains     16 bytes in   1 blocks (ref 0) 0x5605f2ea2ca0
+	 *         no_gsup_server                 contains     15 bytes in   1 blocks (ref 0) 0x5605f2ea2ac0
+	 *         stat_item.c:96                 contains    144 bytes in   2 blocks (ref 0) 0x5605f2ea2950
+	 *             stat_item.c:118                contains     96 bytes in   1 blocks (ref 0) 0x5605f2ea29f0
+	 *         rate_ctr.c:234                 contains   2352 bytes in   1 blocks (ref 0) 0x5605f2ea1fb0
+	 *         sms.db                         contains      7 bytes in   1 blocks (ref 0) 0x5605f2ea1f40
+	 *     logging                        contains   1501 bytes in   5 blocks (ref 0) 0x5605f2ea1360
+	 *         struct log_target              contains    244 bytes in   2 blocks (ref 0) 0x5605f2ea1990
+	 *             struct log_category            contains     76 bytes in   1 blocks (ref 0) 0x5605f2ea1aa0
+	 *         struct log_info                contains   1256 bytes in   2 blocks (ref 0) 0x5605f2ea13d0
+	 *             struct log_info_cat            contains   1216 bytes in   1 blocks (ref 0) 0x5605f2ea1460
+	 *     msgb                           contains      0 bytes in   1 blocks (ref 0) 0x5605f2ea12f0
 	 */
 	fprintf(stderr, "talloc_total_blocks(tall_bsc_ctx) == %zu\n",